@@ -3,22 +3,30 @@
 #
 .getresidualsTransformSubsample <- function(o, y, maxpo, trans, type){
   
+  # Dimensionality of response
+  d <- max(length(dim(y)), 1)
+  
   # a) Transform simulated responses to residuals (unless type == "y")
   sim <- o$store$sim
   if( !is.null(sim) ){
+   
+    if(d == 1){ 
+       sim <- llply(seq_len(nrow(sim)), function(ii) sim[ii, ])
+    } 
+    
     if( type != "y" ){
-      sim <- aaply(sim, 1, 
-                   function(.yy){  
-                     o$y <- .yy
-                     return( residuals(o, type = type) )
-                   }) 
+      sim <- llply(sim, 
+                    function(.yy){  
+                      o$y <- .yy
+                      return( residuals(o, type = type) )
+                    }) 
     }
   }
   
   # b) Apply optional transformation to observed and simulated y's
   if( !is.null(trans) ){
     y <- as.vector(trans( y ))
-    if( !is.null(sim) ) { sim <- t(apply(sim, 1, trans)) }
+    if( !is.null(sim) ) { sim <- llply(sim, trans) }
   }
   
   # c) Sample if too many points (> maxpo) 
@@ -29,6 +37,8 @@
     rep(TRUE, m) 
   }
   
+  if( !is.null(sim) ){ sim <- do.call("rbind", sim) }
+  
   return( list("sim" = sim, "y" = y, "sub" = sub) )
   
 }
