@@ -3,7 +3,7 @@
 #' 
 #' @description This layer adds confidence interval lines to smooth, random or parametric effect plots.
 #'
-#' @param level coverage level (e.g. 0.9 means 90\% intervals). Should be in (0, 1).
+#' @param level coverage level (e.g. 0.9 means 90% intervals). Should be in (0, 1).
 #' @param mul number multiplied by the standard errors when calculating 
 #'            standard error curves. By default \code{NULL}, if
 #'            set to a positive number it will over-ride \code{level}.
@@ -26,7 +26,8 @@ l_ciLine <- function(level = 0.95, mul = NULL, ...){
 
 ######## Internal method 
 #' @noRd
-l_ciLine.1D <- l_ciLine.PtermNumeric <- function(a){
+l_ciLine.1D <- l_ciLine.PtermNumeric <- l_ciLine.PtermMatrixNumeric <- 
+               l_ciLine.ALE1DNumeric <- function(a){
   
   xtra <- a$xtra
   a$xtra <- NULL
