@@ -38,7 +38,8 @@ plot.multi.mgcv.smooth.1D <- function(x, n = 100, xlim = NULL, maxpo = 1e4, tran
   .dat$fit <- data.frame("x" = rep(.fitDat[[1]]$x, length(.fitDat)), 
                          "y" = as.vector( sapply(.fitDat, "[[", "y") ), 
                          "ty" = as.vector( sapply(.fitDat, "[[", "ty") ),  
-                         "id" = rep(.idNam, each = length(.fitDat[[1]]$x)))
+                         "id" = rep(.idNam, each = length(.fitDat[[1]]$x)), 
+                         stringsAsFactors = TRUE)
   if( !isMQGAM ){ 
     .dat$fit$id <- if(is.null(asFact)||asFact){ as.factor(.dat$fit$id) } else { as.numeric(.dat$fit$id) }
   }
